@@ -8,7 +8,7 @@ use Data::Dumper;
 
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 our $AUTOLOAD;
 
 sub new {
@@ -18,7 +18,6 @@ sub new {
     my $self  = {};
 
     $self->{_content}->{version}        = $args->{version} ||= '1.0.0';
-    $self->{_SWAIG}->{defaults}         = {};
     return bless($self, $class);
 }
 
@@ -116,7 +115,7 @@ sub add_aihints {
 sub add_aiswaigdefaults {
     my $self  = shift;
     my $SWAIG = shift;
-    $self->{_SWAIG}->{defaults} //= [];
+    $self->{_SWAIG}->{defaults} //= {};
     
     while ( my ($k,$v) = each(%{$SWAIG}) ) {
 	$self->{_SWAIG}->{defaults}->{$k} = $v;
